Enum MouseEventKind
pub enum MouseEventKind {
Down(MouseButton),
Up(MouseButton),
Drag(MouseButton),
Moved,
ScrollDown,
ScrollUp,
ScrollLeft,
ScrollRight,
}Available on crate feature
term only.Expand description
Variants
Down(MouseButton)
Pressed mouse button. Contains the button that was pressed.
Up(MouseButton)
Released mouse button. Contains the button that was released.
Drag(MouseButton)
Moved the mouse cursor while pressing the contained mouse button.
Moved
Moved the mouse cursor while not pressing a mouse button.
ScrollDown
Scrolled mouse wheel downwards (towards the user).
ScrollUp
Scrolled mouse wheel upwards (away from the user).
ScrollLeft
Scrolled mouse wheel left (mostly on a laptop touchpad).
ScrollRight
Scrolled mouse wheel right (mostly on a laptop touchpad).